@@ -3,11 +3,14 @@ from typing import Any, List, Union
 from .root_loader import RootLoader
 
 
-def load(file_path: str, sub_path: Union[str, List[str]] = "") -> Any:
+def load(file_path: str, sub_path: Union[str, List[str]] = "", *, logging_config_path: str = None) -> Any:
     """Load configuration from a YAML file.
 
     :param file_path: Absolute path to the YAML file containing the configuration
     :param sub_path: path inside the YAML file to load. List elements are noted as 0-based indexes.
+    :param logging_config_path: path inside the YAML file that contains the logging configuration.
+    The format is the same as logging.dictConfig():
+    https://docs.python.org/3/library/logging.config.html#logging-config-dictschema
     :return: the converting dict corresponding to the file.
 
     Taking this file as an example:
@@ -46,4 +49,4 @@ def load(file_path: str, sub_path: Union[str, List[str]] = "") -> Any:
     Loading the sub_path ["top_level_key", "some.dotted.key"] will return "dotted.value"
     """
 
-    return RootLoader(file_path).load_root_file(sub_path)
+    return RootLoader(file_path).load_root_file(sub_path, logging_config_path)
